Module error

Module error 

Enums

AggregateFunctionError
Errors that can occur when executing an aggregate function
GeneratorFunctionError
Errors that can occur when executing a generator function
ScalarFunctionError
Errors that can occur when executing a scalar function

Type Aliases

AggregateFunctionResult
Result type for aggregate function operations
GeneratorFunctionResult
Result type for generator function operations
ScalarFunctionResult
Result type for scalar function operations